# PRObs ontology

This repository contains the "Physical Resources Observatory" (PRObs) ontology. It includes both the concepts and relations as an OWL ontology, Datalog rules, and scripts designed to be run with  the [RDFox triple store](https://www.oxfordsemantic.tech/product). 

This ontology is being developed as part of [UK FIRES](https://ukfires.org).

## Getting started

See the [documentation](https://probs-ontology.netlify.app/) for more information about the ontology concepts and how it can be used.

You can obtain a copy of the ontology files from this git repository, or by installing the Python package `probs_ontology`.

See [probs-ontology-example](https://github.com/ukfires/probs-ontology-example/) for a practical example of using the PRObs system to access resource data.

## Contributing 🎁

Contributions are welcome: share examples of work done using the ontology, make suggestions for improving the documentation, and examples of things that are more difficult than they should be or don't work -- as well as of course making actual fixes to the definitions, scripts and documentation.

See [DEVELOPING.md](DEVELOPING.md) for more information

## Authors

- Stefano Germano
- Carla Saunders
- Rick Lupton

## License

The PRObs ontology is licensed with the **TODO license**
